![logo pykeops](http://www.kernel-operations.io/keops/_images/pykeops_logo.png)

PyKeOps contains the python bindings (numpy and pytorch) for the cpp/cuda library [KeOps](https://www.kernel-operations.io/). It provides
standard python functions that can be used in any **python 3** codes.

For a full documentation you may read:

* [Installation](https://www.kernel-operations.io/keops/introduction/installation.html)
* [Documentation](https://www.kernel-operations.io/)
* [Learning KeOps syntax with examples](https://www.kernel-operations.io/keops/_auto_examples/index.html)
* [Tutorials gallery](https://www.kernel-operations.io/keops/_auto_tutorials/index.html)

# Authors

- [Benjamin Charlier](https://imag.umontpellier.fr/~charlier/)
- [Jean Feydy](https://www.math.ens.fr/~feydy/)
- [Joan Alexis Glaunès](https://www.mi.parisdescartes.fr/~glaunes/)
